==> igniteui-react-core-18.5.2-beta.0.tgz: package/esm5/lib/WebSelectDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSelectItemComponentEventArgsDescriptionMetadata } from "./WebSelectItemComponentEventArgsDescriptionMetadata";
import { VoidEventArgsDescriptionMetadata } from "./VoidEventArgsDescriptionMetadata";
import { WebBaseComboBoxLikeDescriptionMetadata } from "./WebBaseComboBoxLikeDescriptionMetadata";
import { WebSelectDescription } from "./WebSelectDescription";
/**
 * @hidden
 */
var WebSelectDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebSelectDescriptionMetadata, _super);
    function WebSelectDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebSelectDescriptionMetadata.b = function (a) {
        if (WebSelectDescriptionMetadata.a == null) {
            WebSelectDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebSelectDescriptionMetadata.c(WebSelectDescriptionMetadata.a);
        }
        if (a.k(WebSelectDescriptionMetadata.a)) {
            return;
        }
        a.ab(WebSelectDescriptionMetadata.a);
        WebSelectItemComponentEventArgsDescriptionMetadata.d(a);
        VoidEventArgsDescriptionMetadata.d(a);
    };
    WebSelectDescriptionMetadata.c = function (a) {
        WebBaseComboBoxLikeDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:Select");
        a.item("__tagNameWC", "String:igc-select");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("Value", "String");
        a.item("Outlined", "Boolean");
        a.item("Autofocus", "Boolean");
        a.item("Distance", "Number:double");
        a.item("Label", "String");
        a.item("Placeholder", "String");
        a.item("Placement", "ExportedType:string:DropdownPlacement");
        a.item("Placement@names", "Top;TopStart;TopEnd;Bottom;BottomStart;BottomEnd;Right;RightStart;RightEnd;Left;LeftStart;LeftEnd");
        a.item("ScrollStrategy", "ExportedType:string:SelectScrollStrategy");
        a.item("ScrollStrategy@stringUnion", "WebComponents;React");
        a.item("ScrollStrategy@names", "Scroll;Block;Close");
        a.item("Disabled", "Boolean");
        a.item("Required", "Boolean");
        a.item("Invalid", "Boolean");
        a.item("ChangeRef", "EventRef::change");
        a.item("BlurRef", "EventRef::blur");
        a.item("FocusRef", "EventRef::focus");
        a.item("OpeningRef", "EventRef::opening");
        a.item("OpenedRef", "EventRef::opened");
        a.item("ClosingRef", "EventRef::closing");
        a.item("ClosedRef", "EventRef::closed");
    };
    WebSelectDescriptionMetadata.d = function (a) {
        WebSelectDescriptionMetadata.b(a);
        a.ad("WebSelect", function () { return new WebSelectDescription(); });
        a.ac("WebSelect", WebSelectDescriptionMetadata.a);
    };
    WebSelectDescriptionMetadata.$t = markType(WebSelectDescriptionMetadata, 'WebSelectDescriptionMetadata');
    WebSelectDescriptionMetadata.a = null;
    return WebSelectDescriptionMetadata;
}(Base));
export { WebSelectDescriptionMetadata };

==> igniteui-react-core-18.7.0-beta.0.tgz: package/esm5/lib/WebSelectDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSelectItemComponentEventArgsDescriptionMetadata } from "./WebSelectItemComponentEventArgsDescriptionMetadata";
import { VoidEventArgsDescriptionMetadata } from "./VoidEventArgsDescriptionMetadata";
import { WebBaseComboBoxLikeDescriptionMetadata } from "./WebBaseComboBoxLikeDescriptionMetadata";
import { WebSelectDescription } from "./WebSelectDescription";
/**
 * @hidden
 */
var WebSelectDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebSelectDescriptionMetadata, _super);
    function WebSelectDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebSelectDescriptionMetadata.b = function (a) {
        if (WebSelectDescriptionMetadata.a == null) {
            WebSelectDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebSelectDescriptionMetadata.c(WebSelectDescriptionMetadata.a);
        }
        if (a.k(WebSelectDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebSelectDescriptionMetadata.a);
        WebSelectItemComponentEventArgsDescriptionMetadata.d(a);
        VoidEventArgsDescriptionMetadata.d(a);
    };
    WebSelectDescriptionMetadata.c = function (a) {
        WebBaseComboBoxLikeDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:Select");
        a.item("__tagNameWC", "String:igc-select");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("Value", "String");
        a.item("Outlined", "Boolean");
        a.item("Autofocus", "Boolean");
        a.item("Distance", "Number:double");
        a.item("Label", "String");
        a.item("Placeholder", "String");
        a.item("Placement", "ExportedType:string:DropdownPlacement");
        a.item("Placement@names", "Top;TopStart;TopEnd;Bottom;BottomStart;BottomEnd;Right;RightStart;RightEnd;Left;LeftStart;LeftEnd");
        a.item("ScrollStrategy", "ExportedType:string:SelectScrollStrategy");
        a.item("ScrollStrategy@stringUnion", "WebComponents;React");
        a.item("ScrollStrategy@names", "Scroll;Block;Close");
        a.item("Disabled", "Boolean");
        a.item("Required", "Boolean");
        a.item("Name", "String");
        a.item("Invalid", "Boolean");
        a.item("ChangeRef", "EventRef::change");
        a.item("FocusRef", "EventRef::focus");
        a.item("BlurRef", "EventRef::blur");
        a.item("OpeningRef", "EventRef::opening");
        a.item("OpenedRef", "EventRef::opened");
        a.item("ClosingRef", "EventRef::closing");
        a.item("ClosedRef", "EventRef::closed");
    };
    WebSelectDescriptionMetadata.d = function (a) {
        WebSelectDescriptionMetadata.b(a);
        a.ae("WebSelect", function () { return new WebSelectDescription(); });
        a.ad("WebSelect", WebSelectDescriptionMetadata.a);
    };
    WebSelectDescriptionMetadata.$t = markType(WebSelectDescriptionMetadata, 'WebSelectDescriptionMetadata');
    WebSelectDescriptionMetadata.a = null;
    return WebSelectDescriptionMetadata;
}(Base));
export { WebSelectDescriptionMetadata };
